Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Mobile Hub.

Actions, resources, and condition keys for AWS Mobile Hub - Service Authorization Reference

# Actions, resources, and condition keys for AWS Mobile Hub

AWS Mobile Hub (service prefix: `mobilehub` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Mobile Hub
- Resource types defined by AWS Mobile Hub
- Condition keys for AWS Mobile Hub

## Actions defined by AWS Mobile Hub

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateProject | Create a project | Write |  |  |
CreateServiceRole | Enable AWS Mobile Hub in the account by creating the required service role | Write |  |  |
DeleteProject | Delete the specified project | Write | project* |  |
DeleteProjectSnapshot | Delete a saved snapshot of project configuration | Write |  |  |
DeployToStage | Deploy changes to the specified stage | Write |  |  |
DescribeBundle | Describe the download bundle | Read |  |  |
ExportBundle | Export the download bundle | Read |  |  |
ExportProject | Export the project configuration | Read | project* |  |
GenerateProjectParameters | Generate project parameters required for code generation | Read | project* |  |
GetProject | Get project configuration and resources | Read | project* |  |
GetProjectSnapshot | Fetch the previously exported project configuration snapshot | Read |  |  |
ImportProject | Create a new project from the previously exported project configuration | Write |  |  |
InstallBundle | Install a bundle in the project deployments S3 bucket | Write |  |  |
ListAvailableConnectors | List the available SaaS (Software as a Service) connectors | List |  |  |
ListAvailableFeatures | List available features | List |  |  |
ListAvailableRegions | List available regions for projects | List |  |  |
ListBundles | List the available download bundles | List |  |  |
ListProjectSnapshots | List saved snapshots of project configuration | List |  |  |
ListProjects | List projects | List |  |  |
SynchronizeProject | Synchronize state of resources into project | Write | project* |  |
UpdateProject | Update project | Write | project* |  |
ValidateProject | Validate a mobile hub project. | Read |  |  |
VerifyServiceRole | Verify AWS Mobile Hub is enabled in the account | Read |  |  |

## Resource types defined by AWS Mobile Hub

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
project | `arn:$ { Partition}:mobilehub:$ { Region}:$ { Account}:project/$ { ProjectId}` |

## Condition keys for AWS Mobile Hub

Mobile Hub has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.